##  Status
As an Admin you can configure the displayed status for each Fact Sheet.
![Status configuration screen for a new portal, showing status options and color settings.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2755927e7a4410149015a3bf01bfa523_LowRes.png)
